==> haskell-unliftio-core-0.1.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.1.0
id: unliftio-core-0.1.1.0-3wrHy3Ijr0BBoYMyh4oX3g
key: unliftio-core-0.1.1.0-3wrHy3Ijr0BBoYMyh4oX3g
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
abi: 3d84d39d4127f80327155ddec46e058f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unliftio-core-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/unliftio-core-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/unliftio-core-0.1.1.0
hs-libraries: HSunliftio-core-0.1.1.0-3wrHy3Ijr0BBoYMyh4oX3g
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.1.1.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.1.0
id: unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
key: unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
abi: 1c7a6d4dd36bdfc42b4932ebc332e3b3
exposed: True
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-core-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-core-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unliftio-core-0.1.1.0
hs-libraries: HSunliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
